

class WritingFieldMiddleware(object):

    def process_response(self, request, response):
        if request.META.get('HTTP_X_FROM_WRITINGFIELD') == 'True':

            # for cookies
            response.delete_cookie('messages')

            # for session
            try:
                del(request.session['_messages'])
            except KeyError:
                pass

        return response



from os import path
import json


def get_version():
    """returns a pep compliant version number"""

    fp = open(
        path.join(
            path.dirname(path.abspath(__file__)),
            'version.json'
        )
    )
    package = json.load(fp)
    fp.close()
    return package['version']



import os
from distutils.core import setup
from writingfield import get_version

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name='django-writingfield',
    version=get_version(),
    license='BSD 3 Clause',
    description='A fullscreen textfield widget for Django',
    long_description=open('README.rst').read(),
    author='Jamie Curle',
    author_email='jamie@curle.io',
    url='https://github.com/jamiecurle/django-writingfield',
    package_data={
        'writingfield': [
            'static/writingfield/*.js',
            'static/writingfield/*.css',
            'version.json',
        ],
    },
    install_requires=[
        'django >= 1.4.10'
    ],
    packages=[
        'writingfield',
    ])



import json
from os import path

from django.forms import Textarea

from version import get_version


class FullScreenTextarea(Textarea):

    def __init__(self, attrs=None):
        # defaults
        default_attrs = {'class': 'fullscreen'}

        # save original class before smashing it up
        try:
            original_class = attrs['class']
        except (KeyError, TypeError):
            original_class = None

        # update attrs with defaults, or set to default
        try:
            attrs.update(default_attrs)
        except AttributeError:
            attrs = default_attrs

        # make sure fullscreen is always in attrs
        if original_class:
            attrs['class'] += ' {}'.format(original_class)

        # call the super
        super(FullScreenTextarea, self).__init__(attrs)

    class Media:

        version = get_version()

        css = {
            'screen': (
                '//fonts.googleapis.com/css?family=Roboto',
                'writingfield/app.min-{}.css'.format(version))
        }
        js = (
            'writingfield/app.min-{}.js'.format(version),
        )
